@@ -212,8 +212,8 @@ void NetworkManager::Device::propertyChanged(const QString &property, const QVar
         }
         foreach (const QString &availableConnection, d->availableConnections) {
             if (!newAvailableConnections.contains(availableConnection)) {
-                emit availableConnectionDisappeared(availableConnection);
                 d->availableConnections.removeOne(availableConnection);
+                emit availableConnectionDisappeared(availableConnection);
             }
         }
         emit availableConnectionChanged();
@@ -495,11 +495,21 @@ void NetworkManager::Device::deviceStateChanged(uint new_state, uint old_state,
 
 void NetworkManager::Device::propertiesChanged(const QVariantMap &properties)
 {
+    Q_D(Device);
+
     QVariantMap::const_iterator it = properties.constBegin();
     while (it != properties.constEnd()) {
         propertyChanged(it.key(), it.value());
         ++it;
     }
+
+    // FIXME workaround, we need to get a path to updated IPv[46]Config,
+    // because NM doesn't emit the updated value when the device is activated
+    // BUG: https://bugzilla.gnome.org/show_bug.cgi?id=725657
+    if (properties.contains(QLatin1String("State")) && d->connectionState == NetworkManager::Device::Activated) {
+        propertyChanged(QLatin1String("Ip4Config"), QVariant::fromValue<QDBusObjectPath>(d->deviceIface.ip4Config()));
+        propertyChanged(QLatin1String("Ip6Config"), QVariant::fromValue<QDBusObjectPath>(d->deviceIface.ip6Config()));
+    }
 }
 
 NetworkManager::Device::Type NetworkManager::Device::type() const
