@@ -1,23 +1,24 @@
 /*
-Copyright 2008,2011 Will Stephenson <wstephenson@kde.org>
-Copyright 2011-2013 Lamarque V. Souza <lamarque@kde.org>
-Copyright 2013 Daniel Nicoletti <dantti12@gmail.com>
+    Copyright 2008,2011 Will Stephenson <wstephenson@kde.org>
+    Copyright 2011-2013 Lamarque V. Souza <lamarque@kde.org>
+    Copyright 2013 Daniel Nicoletti <dantti12@gmail.com>
+    Copyright 2013 Jan Grulich <jgrulich@redhat.com>
 
-This library is free software; you can redistribute it and/or
-modify it under the terms of the GNU Lesser General Public
-License as published by the Free Software Foundation; either
-version 2.1 of the License, or (at your option) version 3, or any
-later version accepted by the membership of KDE e.V. (or its
-successor approved by the membership of KDE e.V.), which shall
-act as a proxy defined in Section 6 of version 3 of the license.
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Lesser General Public
+    License as published by the Free Software Foundation; either
+    version 2.1 of the License, or (at your option) version 3, or any
+    later version accepted by the membership of KDE e.V. (or its
+    successor approved by the membership of KDE e.V.), which shall
+    act as a proxy defined in Section 6 of version 3 of the license.
 
-This library is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-Lesser General Public License for more details.
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Lesser General Public License for more details.
 
-You should have received a copy of the GNU Lesser General Public
-License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    You should have received a copy of the GNU Lesser General Public
+    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 #ifndef NETWORKMANAGERQT_DEVICE_H
@@ -451,7 +452,7 @@ protected:
      */
     virtual void propertyChanged(const QString &property, const QVariant &value);
 
-    DevicePrivate *d_ptr;
+    DevicePrivate *const d_ptr;
 
 protected Q_SLOTS:
     void deviceStateChanged(uint, uint, uint);
@@ -477,7 +478,7 @@ public:
 private:
     Q_DECLARE_PRIVATE(DeviceStateReason)
 
-    DeviceStateReasonPrivate *d_ptr;
+    DeviceStateReasonPrivate *const d_ptr;
 };
 
 }
